from setuptools import setup

setup(
    name='simple_rest_server',
    version='1.0.4',
    packages=[''],
    url='https://gitlab.com/pavel_lavi/simple-rest-server',
    license='MIT',
    author='Pavel Lavi',
    author_email='LaviPavel@outlook.com',
    description='simple rest server based on flask, useful for api testing'
)
